package com.zhiyun.mqtt.config.mqtt;

import com.alibaba.fastjson.JSON;
import com.zhiyun.mqtt.model.*;
import com.zhiyun.mqtt.redis.DeviceManager;
import com.zhiyun.mqtt.service.*;
import com.zhiyun.mqtt.utils.CodeGenerator;
import com.zhiyun.mqtt.utils.GaoDeApiUtil;
import com.zhiyun.mqtt.websocket.WebSocketServer;
import org.springframework.stereotype.Component;

import javax.annotation.Resource;

/**
 * MQTT 消息返回处理类
 *
 * @author yang xiao kun
 * create on 2021/1/19
 */
@Component
public class MqttCallbackHandler {

    @Resource
    private DeviceService deviceService;
    @Resource
    private SetToDeviceService setToDeviceService;
    @Resource
    private DeviceLocationService deviceLocationService;
    @Resource
    private GaoDeApiUtil gaoDeApiService;
    @Resource
    private DeviceManager deviceRedisService;
    @Resource
    private WebSocketServer webSocketServer;
    @Resource
    private CallRecordsService callRecordsService;

    /**
     * 处理消息
     *
     * @param topic   主题
     * @param payload 消息内容
     */
    void handle(String topic, String payload) {
        if (topic.contains("/")) {
            webSocketServer.massMessage(topic.split("/")[1], payload);
        }
        //消息返回JSON转Object
        MqttMsgDto msgObject = JSON.parseObject(payload, MqttMsgDto.class);
        //根据报文标识代码 M 处理消息
        switch (msgObject.getM()) {
            case "10"://设备端注册报文
                registerDevice(msgObject);
                break;
            case "12"://设备注册完成
                setToDeviceService.registerOK(msgObject.getData().get("deviceid").toString());
                break;
            case "20":// 设备位置信息上报
                LocationHandler(msgObject);
                break;
            case "40"://设备上传通话记录
                CallRecordsHandler(msgObject);
                break;
//            case "30"://设备联网后发送消息,请求更新设置
//                getDeviceSet(msgObject);
//            case "40": // 基站信息
//                String deviceId = msgObject.getR().split("/")[1];
//                baseStationService.insertBaseStation(deviceId, msgObject.getData());
//                break;
        }
    }

    /**
     * 注册设备
     */
    private void registerDevice(MqttMsgDto obj) {
        String num = obj.getData().get("num").toString();
        //查询数据库中是否有此设备
        Device device = deviceService.getByNum(num);
        if (device == null) {
            device = new Device(num, CodeGenerator.generateClientId(), CodeGenerator.generateShortUuid());
            //没有该设备,保存至数据库
            deviceService.save(device);
        }
        //发送消息
        setToDeviceService.returnCodeToDevice(device.getNum(), device.getClientId(), device.getPassword());
    }

    /**
     * 处理上传位置
     */
    private void LocationHandler(MqttMsgDto obj) {
        DeviceLocation location = new DeviceLocation(obj);
        // 逆地理位置解析
        location.setSite(gaoDeApiService.regeo(location.getLonGcj(), location.getLatGcj()));
        // 保存位置信息--历史记录
        deviceLocationService.save(location);
        // 将最新位置信息保存至redis中
        deviceRedisService.saveLocation(location);
        // 通知设备更新未接收到的设置信息
        //setToDeviceService.notifyDeviceUpdateSet(setUpdateTagService.getByDeviceId(location.getDeviceId()));
    }

    /**
     * 设备上传通话记录
     */
    private void CallRecordsHandler(MqttMsgDto obj) {
        CallRecords callRecords = new CallRecords();
        callRecords.setDeviceId(obj.getR().split("/")[1]);
        callRecords.setType((int) obj.getData().get("type"));
        callRecords.setKey((String) obj.getData().get("key"));
        callRecords.setPhoneNum((String) obj.getData().get("phnoenum"));
        callRecords.setTalkTime((int) obj.getData().get("talktime"));
        callRecords.setEndTime((String) obj.getData().get("endtime"));
        callRecordsService.save(callRecords);
    }

//    /**
//     * 获取设备更新设置
//     */
//    private void getDeviceSet(MqttMsgDto obj) {
//        String deviceId = obj.getR().split("/")[1];
//        // res = 1,代表设备中设置更新完毕
//        if (obj.getData().get("res").toString().equals("1")) {
//            //设备更新完成,数据库保持同步
//            setUpdateTagService.updateMsgConfirm(deviceId, obj.getData().get("settag").toString(), "0");
//        }
//        // res = 0,代表设备中设置需要更新
//        if (obj.getData().get("res").toString().equals("0")) {
//            switch (obj.getData().get("settag").toString()) {
//                case Constant.TAG_uploadTag://数据上传频率
//                    SetOther uploadTag = setOtherService.getNetwork(deviceId);
//                    setToDeviceService.setNetwork(BeanUtil.cast(uploadTag, NetWorkSetIO.class));
//                    break;
//                case Constant.TAG_ownTag://持有者配置
//                    break;
//                case Constant.TAG_sosTag:// 紧急联系人设置
//                    SetSOS sosTag = setSosService.getOne(new QueryWrapper<SetSOS>().eq("deviceId", deviceId));
//                    setToDeviceService.setSOS(BeanUtil.cast(sosTag, SosSetIO.class));
//                    break;
//                case Constant.TAG_valTag://音量设置
//                    SetOther valTag = setOtherService.getVolume(deviceId);
//                    setToDeviceService.setVolume(BeanUtil.cast(valTag, VolumeSetIO.class));
//                    break;
//                case Constant.TAG_timeTag://整点报时设置
//                    break;
//                case Constant.TAG_hangonTag://自动接听设置
//                    SetOther hongonTag = setOtherService.getAutoAnswerAndClock(deviceId);
//                    setToDeviceService.setAutoAnswer(BeanUtil.cast(hongonTag, AnswerSetIO.class));
//                    break;
//                case Constant.TAG_whiteTag: //白名单设置
//                    SetOther whiteTag = setOtherService.getWhite(deviceId);
//                    setToDeviceService.setWhitePhone(BeanUtil.cast(whiteTag, WhitePhoneSetIO.class));
//                    break;
//                case Constant.TAG_serverTag://服务器设置
//                    break;
//                case Constant.TAG_msgTag://语音播报内容设置
//
//            }
//        }
//    }
}
