package com.zhiyun.mqtt.controller;

import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.zhiyun.mqtt.common.ServerResponse;
import com.zhiyun.mqtt.common.io.wechat.UserDeviceRelationIO;
import com.zhiyun.mqtt.model.UserDeviceRelation;
import com.zhiyun.mqtt.service.DeviceService;
import com.zhiyun.mqtt.service.RelationService;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import javax.annotation.Resource;

/**
 * 用户设备绑定关系
 *
 * @author chen_yi
 * Create on 2020/8/1
 */
@RestController
@RequestMapping("zy4g/api/relation")
public class RelationController {

    @Resource
    private RelationService relationService;

    @Resource
    private DeviceService deviceService;

    /**
     * 添加绑定关系
     */
    @PostMapping("bind.do")
    public ServerResponse bind(UserDeviceRelationIO io) {
        if (deviceService.getByNum(io.getDeviceNum()) == null)
            return ServerResponse.createByWarningMsg("无效设备码!");
        if (relationService.getByDeviceNum(io.getDeviceNum()) != null)
            return ServerResponse.createByWarningMsg("该设备已经有用户绑定!");
        relationService.saveEntity(io);
        return ServerResponse.createBySuccess();
    }

    /**
     * 解除绑定关系
     */
    @PostMapping("unbind￿.do")
    public ServerResponse unbind(String deviceNum) {
        relationService.delByDeviceNum(deviceNum);
        return ServerResponse.createBySuccess();
    }

    /**
     * 查询用户的所有设备
     */
    @GetMapping("getListByUserId.do")
    public ServerResponse getListByUserId(String userId) {
        return ServerResponse.createBySuccess(relationService.getListByUserId(userId));
    }

    /**
     * 修改默认设备
     * 即登陆以后使用那个设备
     *
     * @param userId    用户ID
     * @param deviceNum 设备码
     */
    @PostMapping("changeDefaultDev.do")
    public ServerResponse changeDefaultDev(String userId, String deviceNum) {
        //删除上一个默认设备
        relationService.update(Wrappers.<UserDeviceRelation>lambdaUpdate().eq(UserDeviceRelation::getIsDefault, 1)
                .eq(UserDeviceRelation::getUserId, userId).set(UserDeviceRelation::getIsDefault, 0));
        //添加新的默认设备
        relationService.update(Wrappers.<UserDeviceRelation>lambdaUpdate().eq(UserDeviceRelation::getDeviceNum, deviceNum)
                .set(UserDeviceRelation::getIsDefault, 1));
        return ServerResponse.createBySuccess();
    }
}
