package com.zhiyun.mqtt.model;

import com.baomidou.mybatisplus.annotation.TableId;
import com.baomidou.mybatisplus.annotation.TableName;
import com.zhiyun.mqtt.utils.CoordTransformUtil;
import com.zhiyun.mqtt.utils.DateTimeUtil;
import lombok.Data;
import lombok.NoArgsConstructor;

import java.time.LocalDateTime;
import java.time.format.DateTimeFormatter;

/**
 * 设备定位相关
 * Created by konglilia on 2020/5/27.
 */
@Data
@TableName("zy_location")
@NoArgsConstructor
public class DeviceLocation {

    @TableId
    private Integer id;

    /**
     * 设备ID
     */
    private String deviceId;

    /**
     * 电量
     */
    private Integer batteryNum;

    /**
     * 信号强度
     */
    private Integer signalNum;

    /**
     * 0:无法定位，1：北斗定位，2：基站定位，3：GPS定位
     */
    private Integer mode;

    /**
     * 经度
     */
    private String lon;

    /**
     * 纬度
     */
    private String lat;

    /**
     * 经度(gcj)
     */
    private String lonGcj;

    /**
     * 纬度(gcj)
     */
    private String latGcj;

    /**
     * 格式化的地理位置
     */
    private String site;

    /**
     * 速度
     */
    private String speed;

    /**
     * 收星颗数
     */
    private Integer num;

    /**
     * 创建时间
     */
    private LocalDateTime createTime;

    /**
     * 数据上传时间
     */
    private LocalDateTime uploadTime;

    /**
     * 当前和临近位置区、小区以及信号强度的拼接字符串
     */
    private String cellInfo;


    public DeviceLocation(MqttMsgDto obj) {
        this.deviceId = obj.getR().split("/")[1];
        this.batteryNum = (int) obj.getData().get("batterynum");
        this.signalNum = (int) obj.getData().get("signalnum");
        this.mode = (int) obj.getData().get("mode");
        this.lon = obj.getData().get("lon").toString();
        this.lat = obj.getData().get("lat").toString();
        this.speed = obj.getData().get("speed").toString();
        this.num = (int) obj.getData().get("num");
        this.uploadTime = LocalDateTime.parse(obj.getData().get("createtime").toString(),
                DateTimeFormatter.ofPattern(DateTimeUtil.Pattern_YDMHMS));
        this.createTime = LocalDateTime.now();
        this.cellInfo = obj.getData().get("cellInfo").toString();
        //转换后的坐标
        String[] gcj = CoordTransformUtil.wgs84toGcj02(this.lon, this.lat);
        this.lonGcj = gcj[0];
        this.latGcj = gcj[1];
    }
}
