package com.zhiyun.mqtt.service;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.zhiyun.mqtt.mapper.BaseStationMapper;
import com.zhiyun.mqtt.model.BaseStation;
import org.springframework.stereotype.Service;

import java.time.LocalDateTime;
import java.util.List;
import java.util.Map;

/**
 * 基站信息
 *
 * @author chenyi
 * Create on 2020/4/10
 */
@Service
public class BaseStationService extends ServiceImpl<BaseStationMapper, BaseStation> {
    /**
     * 添加基站信息,保留最新的,有则更新,无则添加
     *
     * @param deviceId 设备ID
     * @param data     设备发来MQTT 消息对象
     */
    public void insertBaseStation(String deviceId, Map<String, Object> data) {
        BaseStation entity = new BaseStation();
        entity.setCellInf0((String) data.get("cellinf0"));
        entity.setCellInf1((String) data.get("cellinf1"));
        entity.setCreateTime(LocalDateTime.now());
        QueryWrapper<BaseStation> queryWrapper = new QueryWrapper<BaseStation>().eq("deviceId", deviceId);
        saveOrUpdate(entity, queryWrapper);
    }

    /**
     * 通过设备ID查询基站信息
     *
     * @param deviceId 设备ID
     */
    public List<BaseStation> getByDeviceId(String deviceId) {
        return baseMapper.selectList(new QueryWrapper<BaseStation>().eq("deviceId", deviceId));
    }
}
