package com.zhiyun.mqtt.service;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.zhiyun.mqtt.common.io.wechat.UserDeviceRelationIO;
import com.zhiyun.mqtt.mapper.UserDeviceRelationMapper;
import com.zhiyun.mqtt.model.UserDeviceRelation;
import com.zhiyun.mqtt.common.vo.DeviceVo;
import com.zhiyun.mqtt.utils.BeanUtil;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.List;


/**
 * 用户设备绑定关系Service
 *
 * @author chenyi
 * Create on 2020/4/10
 */
@Service
public class RelationService extends ServiceImpl<UserDeviceRelationMapper, UserDeviceRelation> {

    @Resource
    private DeviceService deviceService;

    /**
     * 添加绑定关系
     *
     * @param io 实体类
     */
    public void saveEntity(UserDeviceRelationIO io) {
        int isDefault = getDefaultDeviceNum(io.getUserId()) == null ? 1 : 0;
        UserDeviceRelation entity = BeanUtil.cast(io, UserDeviceRelation.class);
        entity.setIsDefault(isDefault);
        baseMapper.insert(entity);
        deviceService.updateName(io.getDeviceNum(), io.getDeviceName());
    }

    /**
     * 通过设备号删除绑定关系
     *
     * @param deviceNum 设备号
     */
    public void delByDeviceNum(String deviceNum) {
        baseMapper.delete(new QueryWrapper<UserDeviceRelation>().eq("deviceNum", deviceNum));
    }

    /**
     * 查询用户绑定的设备集合
     *
     * @param userId 用户ID
     */
    public List<DeviceVo> getListByUserId(String userId) {
        return baseMapper.getListByUserId(userId);
    }

    /**
     * 通过用户ID 查询默认设备的设备num
     *
     * @param userId 用户Id
     */
    private String getDefaultDeviceNum(String userId) {
        return baseMapper.getDefaultDeviceNum(userId);
    }

    /**
     * 查询设备是否有绑定关系
     *
     * @param deviceNum 设备号
     */
    public UserDeviceRelation getByDeviceNum(String deviceNum) {
        return baseMapper.selectOne(new QueryWrapper<UserDeviceRelation>().eq("deviceNum", deviceNum));
    }
}
