package com.zhiyun.mqtt.service;

import com.zhiyun.mqtt.common.Constant;
import com.zhiyun.mqtt.common.io.wechat.*;
import com.zhiyun.mqtt.config.mqtt.MqttGateway;
import com.zhiyun.mqtt.model.MqttMsgDto;
import org.springframework.stereotype.Component;

import javax.annotation.Resource;
import java.util.HashMap;
import java.util.Map;

/**
 * 设置设备服务类,发送远程消息
 *
 * @author yang xiao kun
 * create on 2021/2/1
 */
@Component
public class SetToDeviceService {
    @Resource
    private MqttGateway mqttGateway;

    /**
     * 设置音量
     *
     * @param io 设置参数
     */
    public void setVolume(VolumeSetIO io) {
        //发送模板消息给设备
        MqttMsgDto msg = new MqttMsgDto(Constant.M_CODE_VOLUME, io.getDeviceId());
        msg.set("msgvol", io.getMsgVol())
                .set("phonevol", io.getPhoneVol())
                .set("ringvol", io.getRingVol());
        mqttGateway.sendMsgToMqtt(msg.toJson(), io.getTopic());
    }

    /**
     * 设置定位频率
     *
     * @param io 设置参数
     */
    public void setGpsRate(GpsRateSetIO io) {
        //发送模板消息给设备
        MqttMsgDto msg = new MqttMsgDto(Constant.M_CODE_GPS_RATE, io.getDeviceId());
        msg.set("GPS_rate", io.getGpsRate());
        mqttGateway.sendMsgToMqtt(msg.toJson(), io.getTopic());
    }

    /**
     * 自动接听
     *
     * @param io 设置参数
     */
    public void setAutoAnswer(AnswerSetIO io) {
        //发送模板消息给设备
        MqttMsgDto msg = new MqttMsgDto(Constant.M_CODE_AUTO_ANSWER, io.getDeviceId());
        msg.set("autoanswer", io.getAutoAnswer());
        mqttGateway.sendMsgToMqtt(msg.toJson(), io.getTopic());
    }

    /**
     * 设置语音播报
     */
    public void sendNews(NewsSetIO io) {
        //发送模板消息给设备
        MqttMsgDto msg = new MqttMsgDto(Constant.M_CODE_NEWS, io.getDeviceId());
        msg.set("newstype", io.getNewsType())
                .set("newstime", io.getNewsTime())
                .set("news", io.getNews());
        mqttGateway.sendMsgToMqtt(msg.toJson(), io.getTopic());
    }

    /**
     * 设置SOS紧急呼叫
     */
    public void setSOS(SosSetIO io) {
        //发送模板消息给设备
        MqttMsgDto msg = new MqttMsgDto(Constant.M_CODE_SOS, io.getDeviceId());
        msg.set("key0_name", io.getKey0Name())
                .set("key0_phone", io.getKey0Phone())
                .set("key1_name", io.getKey1Name())
                .set("key1_phone", io.getKey1Phone())
                .set("key2_name", io.getKey2Name())
                .set("key2_phone", io.getKey2Phone());
        mqttGateway.sendMsgToMqtt(msg.toJson(), io.getTopic());
    }

    /**
     * 设置持续定位
     */
    public void setContinue(ContinueSetIO io) {
        //发送模板消息给设备
        MqttMsgDto msg = new MqttMsgDto(Constant.M_CODE_CONTINUE_GPS, io.getDeviceId());
        msg.set("highfreq", io.getHighFreq());
        mqttGateway.sendMsgToMqtt(msg.toJson(), io.getTopic());
    }

    /**
     * 服务器返回授权码
     *
     * @param regNum   设备码
     * @param clientId MQTT 客户端码
     * @param password MQTT 客户端连接密码
     */
    public void returnCodeToDevice(String regNum, String clientId, String password) {
        //发送模板消息给设备
        MqttMsgDto msg = new MqttMsgDto();
        msg.setM(Constant.M_CODE_RETURN_CODE);
        msg.setR("$regdtx");
        msg.setT("$regdrx");
        Map<String, Object> data = new HashMap<>();
        data.put("regnum", regNum);
        data.put("deviceid", clientId);
        data.put("password", password);
        msg.setData(data);
        mqttGateway.sendMsgToMqtt(msg.toJson(), Constant.TOPIC_REGISTER_CLIENT);
    }

    /**
     * 注册完成
     *
     * @param clientId MQTT 客户端码
     */
    public void registerOK(String clientId) {
        //发送模板消息给设备
        MqttMsgDto msg = new MqttMsgDto();
        msg.setM(Constant.M_CODE_REGISTER_OK);
        msg.setR("$regdtx");
        msg.setT("$regdrx");
        Map<String, Object> data = new HashMap<>();
        data.put("deviceid", clientId);
        msg.setData(data);
        mqttGateway.sendMsgToMqtt(msg.toJson(), Constant.TOPIC_REGISTER_CLIENT);
    }

//    /**
//     * 设置服务器端口号
//     */
//    public void setServer(ServerSetIO io) {
//        //发送模板消息给设备
//        MqttMsgDto msg = new MqttMsgDto(Constant.M_CODE_SERVER, io.getDeviceId());
//        msg.set("serverhost", io.getServerHost()).set("serverport", io.getServerPort());
//        mqttGateway.sendMsgToMqtt(msg.toJson(), io.getTopic());
//    }
//    /**
//     * 通知设备更新设置
//     *
//     * @param tag 更新设置tag
//     */
//    public void notifyDeviceUpdateSet(SetUpdateTag tag) {
//        //都等于零 说明无更新,则不发送
//        if (tag == null || (tag.getHangontag().equals("0") && tag.getMsgtag().equals("0") && tag.getWhitetag().equals("0")
//                && tag.getOwntag().equals("0") && tag.getServertag().equals("0") && tag.getSostag().equals("0")
//                && tag.getTimetag().equals("0") && tag.getUploadtag().equals("0") && tag.getValtag().equals("0"))) {
//            return;
//        }
//        //发送模板消息给设备
//        MqttMsgDto msg = new MqttMsgDto(Constant.M_CODE_CONFIG_TAG, tag.getDeviceId());
//        msg.set("deviceid", tag.getDeviceId())
//                .set("uploadtag", tag.getUploadtag())
//                .set("owntag", tag.getOwntag())
//                .set("sostag", tag.getSostag())
//                .set("valtag", tag.getValtag())
//                .set("timetag", tag.getTimetag())
//                .set("hongontag", tag.getHangontag())
//                .set("whitetag", tag.getWhitetag())
//                .set("servertag", tag.getServertag())
//                .set("msgtag", tag.getMsgtag());
//        mqttGateway.sendMsgToMqtt(msg.toJson(), Constant.TOPIC_REGISTER_CLIENT);
//    }
}
